==> modx-cms-1.0.3.zip: modx-1.0.3/assets/snippets/ajaxSearch/lang/francais-utf8.inc.php <==
<?php
/*
francais-utf8.inc.php - for AjaxSearch 1.8.2
Created by: KyleJ (kjaebker@muddydogpaws.com), Translated by: David Mollière, Corrected by: Jean-Christophe Brebion
Created on: 01/22/07  Translated on: 04/10/07  Corrected on: 28/07/09
Description: UTF8 French Language file for AjaxSearch
*/
$_lang['as_resultsIntroFailure'] = 'Aucun résultat de recherche. Élargissez votre requête pour obtenir plus de résultats.';
$_lang['as_searchButtonText'] = 'rechercher!';
$_lang['as_boxText'] = 'Saisissez votre recherche ici...';
$_lang['as_introMessage'] = 'Veuillez saisir un terme à rechercher avant de lancer la recherche.';
$_lang['as_resultsFoundTextSingle'] = '%d résultat trouvé pour "%s".';
$_lang['as_resultsFoundTextMultiple'] = '%d résultats trouvés pour "%s".';
$_lang['as_paginationTextSinglePage'] = '';
$_lang['as_paginationTextMultiplePages'] = 'Pages de résultats: ';
$_lang['as_moreResultsText'] = 'Cliquez ici pour voir tous les résultats.';
$_lang['as_moreResultsTitle'] = 'Plus de résultats';
$_lang['as_maxWords'] = 'Un maximum de %d mots sont autorisés pour votre recherche';
$_lang['as_minChars'] = 'Votre terme de recherche doit au moins avoir %d caractères';
$_lang['as_maxChars'] = 'Un terme de recherche ne peut avoir plus de %d caractères';
$_lang['oneword'] = 'Un mot';
$_lang['allwords'] = 'Tous les mots';
$_lang['exactphrase'] = 'Phrase exacte';
$_lang['nowords'] = 'Aucun mot';
$_lang['as_cmtHiddenFieldIntro'] = 'Ce champ doit rester vide. <br />Ne saisir aucun texte.';
$_lang['as_cmtIntroMessage'] = 'Avez-vous trouvé ce que vous recherchiez? Laissez un commentaire ici!';
$_lang['as_cmtSubmitText'] = 'envoyer';
$_lang['as_cmtResetText'] = 'effacer';
$_lang['as_cmtThksMessage'] = 'Merci pour votre commentaire';
?>

==> modx-cms-1.0.12.zip: modx-1.0.12/assets/snippets/ajaxSearch/lang/francais-utf8.inc.php <==
<?php
/*
francais-utf8.inc.php - for AjaxSearch 1.9.0
Created by: KyleJ (kjaebker@muddydogpaws.com), Translated by: David Mollière, Corrected by: Jean-Christophe Brebion
Created on: 01/22/07  Translated on: 04/10/07  Corrected on: 18/05/10
Description: UTF8 French Language file for AjaxSearch
*/
$_lang['as_resultsIntroFailure'] = 'Aucun résultat de recherche. Élargissez votre requête pour obtenir plus de résultats.';
$_lang['as_searchButtonText'] = 'rechercher!';
$_lang['as_boxText'] = 'Saisissez votre recherche ici...';
$_lang['as_introMessage'] = 'Veuillez saisir un terme à rechercher avant de lancer la recherche.';
$_lang['as_resultsFoundTextSingle'] = '%d résultat trouvé pour "%s".';
$_lang['as_resultsFoundTextMultiple'] = '%d résultats trouvés pour "%s".';
$_lang['as_paginationTextSinglePage'] = '';
$_lang['as_paginationTextMultiplePages'] = 'Pages de résultats: ';
$_lang['as_moreResultsText'] = 'Cliquez ici pour voir tous les résultats.';
$_lang['as_moreResultsTitle'] = 'Plus de résultats';
$_lang['as_maxWords'] = 'Un maximum de %d mots sont autorisés pour votre recherche';
$_lang['as_minChars'] = 'Votre terme de recherche doit au moins avoir %d caractères';
$_lang['as_maxChars'] = 'Un terme de recherche ne peut avoir plus de %d caractères';
$_lang['oneword'] = 'Un mot';
$_lang['allwords'] = 'Tous les mots';
$_lang['exactphrase'] = 'Phrase exacte';
$_lang['nowords'] = 'Aucun mot';
$_lang['as_cmtHiddenFieldIntro'] = 'Ce champ doit rester vide. <br />Ne saisir aucun texte.';
$_lang['as_cmtIntroMessage'] = 'Avez-vous trouvé ce que vous recherchiez? Laissez un commentaire ici!';
$_lang['as_cmtSubmitText'] = 'envoyer';
$_lang['as_cmtResetText'] = 'effacer';
$_lang['as_cmtThksMessage'] = 'Merci pour votre commentaire';
$_lang['as_resultsTextSingle'] = '%d résultat trouvé.';
$_lang['as_resultsTextMultiple'] = '%d résultats trouvés.';
$_lang['as_grpResultsDisplayedText'] = '(Affichage de %d - %d / %d)';
$_lang['as_resultsDisplayed'] = 'Affichés : %d';
$_lang['as_paging1Text'] = '%d - %d / %d';
$_lang['as_paging2Text'] = 'Voir %d autres resultats';
?>
